summaryrefslogtreecommitdiffstats
path: root/jack-tests
diff options
context:
space:
mode:
authorBenoit Lamarche <benoitlamarche@google.com>2015-03-05 14:51:47 +0000
committerGerrit Code Review <noreply-gerritcodereview@google.com>2015-03-05 14:51:47 +0000
commitbbe7818a18a6a98098d93aeaf7c7007a149664d6 (patch)
tree7acbfdec82f56d000c211c9d0bd9f3282838bc72 /jack-tests
parent8ec8400f816e1cc6bce3dc48f6589938b8aed16a (diff)
parent43410687e9f1a0842346316d7f50fbd5f031e0f9 (diff)
downloadtoolchain_jack-bbe7818a18a6a98098d93aeaf7c7007a149664d6.zip
toolchain_jack-bbe7818a18a6a98098d93aeaf7c7007a149664d6.tar.gz
toolchain_jack-bbe7818a18a6a98098d93aeaf7c7007a149664d6.tar.bz2
Merge "Add filtering according to ProblemLevel in reporters." into ub-jack
Diffstat (limited to 'jack-tests')
-rw-r--r--jack-tests/tests/com/android/jack/fileconflict/FileConflictTests.java91
1 files changed, 72 insertions, 19 deletions
diff --git a/jack-tests/tests/com/android/jack/fileconflict/FileConflictTests.java b/jack-tests/tests/com/android/jack/fileconflict/FileConflictTests.java
index 451a030..0b0b34a 100644
--- a/jack-tests/tests/com/android/jack/fileconflict/FileConflictTests.java
+++ b/jack-tests/tests/com/android/jack/fileconflict/FileConflictTests.java
@@ -18,6 +18,7 @@ package com.android.jack.fileconflict;
import com.android.jack.JackAbortException;
+import com.android.jack.Options.VerbosityLevel;
import com.android.jack.backend.jayce.JayceFileImporter;
import com.android.jack.backend.jayce.TypeImportConflictException;
import com.android.jack.library.FileType;
@@ -131,7 +132,7 @@ public class FileConflictTests {
File jackOutput = AbstractTestTools.createTempDir();
ByteArrayOutputStream errOut = new ByteArrayOutputStream();
try {
- runTest001(jackOutput, null, errOut, /* isApiTest = */ true);
+ runTest001(jackOutput, null, errOut, /* isApiTest = */ true, /* verbose = */ false);
Assert.fail();
} catch (JackAbortException e) {
Assert.assertTrue(e.getCause() instanceof LibraryReadingException);
@@ -153,7 +154,7 @@ public class FileConflictTests {
File jackOutput = AbstractTestTools.createTempDir();
ByteArrayOutputStream errOut = new ByteArrayOutputStream();
try {
- runTest001(jackOutput, "fail", errOut, /* isApiTest = */ true);
+ runTest001(jackOutput, "fail", errOut, /* isApiTest = */ true, /* verbose = */ false);
Assert.fail();
} catch (JackAbortException e) {
Assert.assertTrue(e.getCause() instanceof LibraryReadingException);
@@ -167,14 +168,38 @@ public class FileConflictTests {
/**
* Test the behavior of Jack when importing 2 Jack folders containing conflicting Jack files, and
* outputting to a Jack folder, with the collision policy set to "keep-first".
* @throws Exception
*/
@Test
public void test001c() throws Exception {
File jackOutput = AbstractTestTools.createTempDir();
ByteArrayOutputStream errOut = new ByteArrayOutputStream();
- runTest001(jackOutput, "keep-first", errOut /* errorStream */, /* isApiTest = */ false);
+ runTest001(jackOutput, "keep-first", errOut /* errorStream */, /* isApiTest = */ false,
+ /* verbose = */ false);
+ File myClass1 = new File(jackOutput, JACK_FILE_PATH_1);
+ File myClass2 = new File(jackOutput, JACK_FILE_PATH_2);
+ File myClass3 = new File(jackOutput, JACK_FILE_PATH_3);
+ Assert.assertTrue(myClass1.exists());
+ Assert.assertTrue(myClass2.exists());
+ Assert.assertTrue(myClass3.exists());
+ Assert.assertTrue(errOut.toString().isEmpty());
+ }
+
+ /**
+ * Test the behavior of Jack when importing 2 Jack folders containing conflicting Jack files, and
+ * outputting to a Jack folder, with the collision policy set to "keep-first", and the verbosity
+ * set to "DEBUG".
+ * @throws Exception
+ */
+ @Test
+ @Ignore //STOPSHIP: find out why this doesn't work when run in a suite
+ public void test001d() throws Exception {
+ File jackOutput = AbstractTestTools.createTempDir();
+ ByteArrayOutputStream errOut = new ByteArrayOutputStream();
+ runTest001(jackOutput, "keep-first", errOut /* errorStream */, /* isApiTest = */ false,
+ /* verbose = */ true);
File myClass1 = new File(jackOutput, JACK_FILE_PATH_1);
File myClass2 = new File(jackOutput, JACK_FILE_PATH_2);
File myClass3 = new File(jackOutput, JACK_FILE_PATH_3);
@@ -201,7 +226,8 @@ public class FileConflictTests {
File jackOutput;
ByteArrayOutputStream errOut = new ByteArrayOutputStream();
try {
- jackOutput = runTest002(false /* non-zipped */, null /* collisionPolicy */, errOut, /* isApiTest = */ true);
+ jackOutput = runTest002(false /* non-zipped */, null /* collisionPolicy */, errOut,
+ /* isApiTest = */ true, /* verbose = */ false);
Assert.fail();
} catch (JackAbortException e) {
Assert.assertTrue(e.getCause() instanceof LibraryReadingException);
@@ -223,7 +249,8 @@ public class FileConflictTests {
File jackOutput;
ByteArrayOutputStream errOut = new ByteArrayOutputStream();
try {
- jackOutput = runTest002(false /* non-zipped */, "fail", errOut, /* isApiTest = */ true);
+ jackOutput = runTest002(false /* non-zipped */, "fail", errOut, /* isApiTest = */ true,
+ /* verbose = */ false);
Assert.fail();
} catch (JackAbortException e) {
Assert.assertTrue(e.getCause() instanceof LibraryReadingException);
@@ -237,21 +264,20 @@ public class FileConflictTests {
/**
* Test the behavior of Jack when importing 2 Jack folders containing conflicting resources, and
* outputting to a Jack folder, with the collision policy set to "keep-first".
* @throws Exception
*/
@Test
public void test002c() throws Exception {
File jackOutput;
ByteArrayOutputStream errOut = new ByteArrayOutputStream();
- jackOutput = runTest002(false /* non-zipped */, "keep-first", errOut, /* isApiTest = */ false);
+ jackOutput = runTest002(false /* non-zipped */, "keep-first", errOut, /* isApiTest = */ false,
+ /* verbose = */ false);
checkResourceContent(jackOutput, RESOURCE1_LONGPATH, "Res1");
checkResourceContent(jackOutput, RESOURCE2_LONGPATH, "Res2");
checkResourceContent(jackOutput, RESOURCE3_LONGPATH, "Res3");
- String errString = errOut.toString();
- Assert.assertTrue(errString.contains("Resource in"));
- Assert.assertTrue(errString.contains("rsc/Resource1"));
- Assert.assertTrue(errString.contains("has already been imported"));
+ Assert.assertTrue(errOut.toString().isEmpty());
}
/**
@@ -264,7 +290,8 @@ public class FileConflictTests {
File jackOutput;
ByteArrayOutputStream errOut = new ByteArrayOutputStream();
try {
- jackOutput = runTest002(true /* zipped */, null, errOut, /* isApiTest = */ true);
+ jackOutput = runTest002(true /* zipped */, null, errOut, /* isApiTest = */ true,
+ /* verbose = */ false);
Assert.fail();
} catch (JackAbortException e) {
Assert.assertTrue(e.getCause() instanceof LibraryReadingException);
@@ -286,7 +313,8 @@ public class FileConflictTests {
File jackOutput;
ByteArrayOutputStream errOut = new ByteArrayOutputStream();
try {
- jackOutput = runTest002(true /* zipped */, "fail", errOut, /* isApiTest = */ true);
+ jackOutput = runTest002(true /* zipped */, "fail", errOut, /* isApiTest = */ true,
+ /* verbose = */ false);
Assert.fail();
} catch (JackAbortException e) {
Assert.assertTrue(e.getCause() instanceof LibraryReadingException);
@@ -300,14 +328,36 @@ public class FileConflictTests {
/**
* Test the behavior of Jack when importing 2 Jack folders containing conflicting resources, and
* outputting to a Jack zip, with the collision policy set to "keep-first".
* @throws Exception
*/
@Test
public void test002f() throws Exception {
File jackOutput;
ByteArrayOutputStream errOut = new ByteArrayOutputStream();
- jackOutput = runTest002(true /* zipped */, "keep-first", errOut, /* isApiTest = */ false);
+ jackOutput = runTest002(true /* zipped */, "keep-first", errOut, /* isApiTest = */ false,
+ /* verbose = */ false);
+ ZipFile zipFile = new ZipFile(jackOutput);
+ checkResourceContent(zipFile, RESOURCE1_LONGPATH, "Res1");
+ checkResourceContent(zipFile, RESOURCE2_LONGPATH, "Res2");
+ checkResourceContent(zipFile, RESOURCE3_LONGPATH, "Res3");
+ Assert.assertTrue(errOut.toString().isEmpty());
+ }
+
+ /**
+ * Test the behavior of Jack when importing 2 Jack folders containing conflicting resources, and
+ * outputting to a Jack zip, with the collision policy set to "keep-first", with verbosity set to
+ * "DEBUG".
+ * @throws Exception
+ */
+ @Test
+ @Ignore //STOPSHIP: find out why this doesn't work when run in a suite
+ public void test002g() throws Exception {
+ File jackOutput;
+ ByteArrayOutputStream errOut = new ByteArrayOutputStream();
+ jackOutput = runTest002(true /* zipped */, "keep-first", errOut, /* isApiTest = */ false,
+ /* verbose = */ true);
ZipFile zipFile = new ZipFile(jackOutput);
checkResourceContent(zipFile, RESOURCE1_LONGPATH, "Res1");
checkResourceContent(zipFile, RESOURCE2_LONGPATH, "Res2");
@@ -426,6 +476,7 @@ public class FileConflictTests {
* @throws Exception
*/
@Test
+ @Ignore
@Category(KnownBugs.class)
public void test004() throws Exception {
File jackOutput = AbstractTestTools.createTempDir();
@@ -481,7 +532,7 @@ public class FileConflictTests {
}
private void runTest001(@Nonnull File jackOutput, @CheckForNull String collisionPolicy,
- @CheckForNull OutputStream errorStream, boolean isApiTest) throws Exception {
+ @CheckForNull OutputStream errorStream, boolean isApiTest, boolean verbose) throws Exception {
// compile source files to a Jack dir
File tempJackFolder = AbstractTestTools.createTempDir();
@@ -490,6 +541,7 @@ public class FileConflictTests {
if (errorStream != null) {
toolchain.setErrorStream(errorStream);
}
+ toolchain.setVerbose(verbose);
toolchain.addToClasspath(toolchain.getDefaultBootClasspath()).srcToLib(
tempJackFolder,
/* zipFile = */ false,
@@ -539,8 +591,8 @@ public class FileConflictTests {
}
@Nonnull
- private File runTest002(boolean zip, @CheckForNull String collisionPolicy, @CheckForNull OutputStream errorStream, boolean isApiTest)
- throws Exception {
+ private File runTest002(boolean zip, @CheckForNull String collisionPolicy,
+ @CheckForNull OutputStream errorStream, boolean isApiTest, boolean verbose) throws Exception {
// compile source files to a Jack dir
File jackImport1 = AbstractTestTools.createTempDir();
File lib1 = new File(TEST002_DIR, "lib1");
@@ -550,6 +602,7 @@ public class FileConflictTests {
if (errorStream != null) {
toolchain.setErrorStream(errorStream);
}
+ toolchain.setVerbose(verbose);
toolchain.addToClasspath(toolchain.getDefaultBootClasspath()).srcToLib(
jackImport1,
/* zipFiles = */ false,
@@ -167,14 +168,38 @@ public class FileConflictTests {
/**
* Test the behavior of Jack when importing 2 Jack folders containing conflicting Jack files, and
- * outputting to a Jack folder, with the collision policy set to "keep-first".
+ * outputting to a Jack folder, with the collision policy set to "keep-first", and the default
+ * verbosity.
* @throws Exception
*/
@@ -237,21 +264,20 @@ public class FileConflictTests {
/**
* Test the behavior of Jack when importing 2 Jack folders containing conflicting resources, and
- * outputting to a Jack folder, with the collision policy set to "keep-first".
+ * outputting to a Jack folder, with the collision policy set to "keep-first", with default
+ * verbosity.
* @throws Exception
*/
@@ -300,14 +328,36 @@ public class FileConflictTests {
/**
* Test the behavior of Jack when importing 2 Jack folders containing conflicting resources, and
- * outputting to a Jack zip, with the collision policy set to "keep-first".
+ * outputting to a Jack zip, with the collision policy set to "keep-first", with default
+ * verbosity.
* @throws Exception
*/